| Title: | Out-of-Treatment Testing |
|---|---|
| Description: | Implements the out-of-treatment testing from Kuelpmann and Kuzmics (2020) <doi:10.2139/ssrn.3441675> based on the Vuong Test introduced in Vuong (1989) <doi:10.2307/1912557>. Out-of treatment testing allows for a direct, pairwise likelihood comparison of theories, calibrated with pre-existing data. |
| Authors: | Philipp Külpmann [aut, cre] (ORCID: <https://orcid.org/0000-0003-3757-7172>), Panagiota Charalampidou [aut], University of Vienna [cph] |
| Maintainer: | Philipp Külpmann <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.9.0 |
| Built: | 2026-05-19 10:35:53 UTC |
| Source: | https://github.com/philippkuelpmann/oottest |
This is the choice data from Kuelpmann and Kuzmics (2022) for the three-action games, i.e., Hawk-Middle-Dove and Rock-Paper-Scissor. For an explanation of the different treatments and the games, please refer to the paper.
data_three_action_gamesdata_three_action_games
Need to reformat anyway ...
actions
treatments
number of subjects who chose each action on each treatment
...
https://homepage.univie.ac.at/philipp.kuelpmann/hdg.html
This is the choice data from Kuelpmann and Kuzmics (2022) for the two-action games, i.e., Hawk-Dove and Matching Pennies. For an explanation of the different treatments and the games, please refer to the paper.
data_two_action_gamesdata_two_action_games
actions
treatments
number of subjects who chose each action on each treatment
...
https://homepage.univie.ac.at/philipp.kuelpmann/hdg.html
These are the prediction of every theory considered in Kuelpmann and Kuzmics (2022) for the three-action games. For a explanation of the different theories, treatments and the games, please refer to the paper.
predictions_three_action_gamespredictions_three_action_games
predicted probabilities of actions
treatments
different theories
probability of choosing an action on each treatment depending on the theory
...
https://homepage.univie.ac.at/philipp.kuelpmann/hdg.html
These are the prediction of every theory considered in Kuelpmann and Kuzmics (2022) for the two-action games. For a explanation of the different theories, treatments and the games, please refer to the paper.
predictions_two_action_gamespredictions_two_action_games
predicted probabilities of actions
treatments
different theories
probability of choosing an action on each treatment depending on the theory
...
https://homepage.univie.ac.at/philipp.kuelpmann/hdg.html
This is just very simple test data, mostly used for testing and demonstration purposes.
simple_test_datasimple_test_data
A matrix with 3 rows and 2 columns
actions
treatments
number of subjects who chose each action on each treatment
...
Getting a vuong matrix
vuong_matrix(data, theories)vuong_matrix(data, theories)
data |
matrix rows: choices, columns: treatments |
theories |
list of matrices each in the same format as above |
Table of z-scores for all comparisons
vuong_matrix(data_two_action_games, predictions_two_action_games)vuong_matrix(data_two_action_games, predictions_two_action_games)
Implementation of the Vuong test for our setting
vuong_statistic(data, pred_i, pred_j)vuong_statistic(data, pred_i, pred_j)
data |
Data of the experiment (matrix of ints/data.frame): columns are treatments, rows are actions, values are number of subjects who chose each action on each treatment |
pred_i |
Model prediction for a theory (matrix of doubles/data.frame): rows are prediction of playing action 1,2,3..., columns are treatments |
pred_j |
Model prediction for a theory (matrix of doubles/data.frame): rows are prediction of playing action 1,2,3..., columns are treatments |
The z score of testing theory I against theory J, given the data
vuong_statistic( data_two_action_games, predictions_two_action_games[, , 1], predictions_two_action_games[, , 2] )vuong_statistic( data_two_action_games, predictions_two_action_games[, , 1], predictions_two_action_games[, , 2] )